@@ -334,9 +334,9 @@ defmodule JOSE.JWE do
   """
 
   record = Record.extract(:jose_jwe, from_lib: "jose/include/jose_jwe.hrl")
-  keys   = :lists.map(&elem(&1, 0), record)
-  vals   = :lists.map(&{&1, [], nil}, keys)
-  pairs  = :lists.zip(keys, vals)
+  keys = :lists.map(&elem(&1, 0), record)
+  vals = :lists.map(&{&1, [], nil}, keys)
+  pairs = :lists.zip(keys, vals)
 
   defstruct keys
   @type t :: %__MODULE__{}
@@ -347,16 +347,19 @@ defmodule JOSE.JWE do
   def to_record(%JOSE.JWE{unquote_splicing(pairs)}) do
     {:jose_jwe, unquote_splicing(vals)}
   end
-  def to_record(list) when is_list(list), do: for element <- list, into: [], do: to_record(element)
+
+  def to_record(list) when is_list(list), do: for(element <- list, into: [], do: to_record(element))
 
   @doc """
   Converts a `:jose_jwe` record into a `JOSE.JWE`.
   """
   def from_record(jose_jwe)
+
   def from_record({:jose_jwe, unquote_splicing(vals)}) do
     %JOSE.JWE{unquote_splicing(pairs)}
   end
-  def from_record(list) when is_list(list), do: for element <- list, into: [], do: from_record(element)
+
+  def from_record(list) when is_list(list), do: for(element <- list, into: [], do: from_record(element))
 
   ## Decode API
 
@@ -383,14 +386,14 @@ defmodule JOSE.JWE do
        zip: {MyCustomCompress, :state}}
 
   """
-  def from(list) when is_list(list), do: for element <- list, into: [], do: from(element)
-  def from(jwe=%JOSE.JWE{}), do: from(to_record(jwe))
+  def from(list) when is_list(list), do: for(element <- list, into: [], do: from(element))
+  def from(jwe = %JOSE.JWE{}), do: from(to_record(jwe))
   def from(any), do: :jose_jwe.from(any) |> from_record()
 
   @doc """
   Converts a binary into a `JOSE.JWE`.
   """
-  def from_binary(list) when is_list(list), do: for element <- list, into: [], do: from_binary(element)
+  def from_binary(list) when is_list(list), do: for(element <- list, into: [], do: from_binary(element))
   def from_binary(binary), do: :jose_jwe.from_binary(binary) |> from_record()
 
   @doc """
@@ -401,7 +404,7 @@ defmodule JOSE.JWE do
   @doc """
   Converts a map into a `JOSE.JWE`.
   """
-  def from_map(list) when is_list(list), do: for element <- list, into: [], do: from_map(element)
+  def from_map(list) when is_list(list), do: for(element <- list, into: [], do: from_map(element))
   def from_map(map), do: :jose_jwe.from_map(map) |> from_record()
 
   ## Encode API
@@ -409,21 +412,21 @@ defmodule JOSE.JWE do
   @doc """
   Converts a `JOSE.JWE` into a binary.
   """
-  def to_binary(list) when is_list(list), do: for element <- list, into: [], do: to_binary(element)
-  def to_binary(jwe=%JOSE.JWE{}), do: to_binary(to_record(jwe))
+  def to_binary(list) when is_list(list), do: for(element <- list, into: [], do: to_binary(element))
+  def to_binary(jwe = %JOSE.JWE{}), do: to_binary(to_record(jwe))
   def to_binary(any), do: :jose_jwe.to_binary(any)
 
   @doc """
   Calls `to_binary/1` on a `JOSE.JWE` and then writes the binary to file.
   """
-  def to_file(file, jwe=%JOSE.JWE{}), do: to_file(file, to_record(jwe))
+  def to_file(file, jwe = %JOSE.JWE{}), do: to_file(file, to_record(jwe))
   def to_file(file, any), do: :jose_jwe.to_file(file, any)
 
   @doc """
   Converts a `JOSE.JWE` into a map.
   """
-  def to_map(list) when is_list(list), do: for element <- list, into: [], do: to_map(element)
-  def to_map(jwe=%JOSE.JWE{}), do: to_map(to_record(jwe))
+  def to_map(list) when is_list(list), do: for(element <- list, into: [], do: to_map(element))
+  def to_map(jwe = %JOSE.JWE{}), do: to_map(to_record(jwe))
   def to_map(any), do: :jose_jwe.to_map(any)
 
   ## API
@@ -444,13 +447,19 @@ defmodule JOSE.JWE do
 
   See `block_encrypt/2`.
   """
-  def block_decrypt(jwk=%JOSE.JWK{}, encrypted), do: block_decrypt(JOSE.JWK.to_record(jwk), encrypted)
-  def block_decrypt({your_public_jwk=%JOSE.JWK{}, my_private_jwk}, encrypted), do: block_decrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, encrypted)
-  def block_decrypt({your_public_jwk, my_private_jwk=%JOSE.JWK{}}, encrypted), do: block_decrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, encrypted)
+  def block_decrypt(jwk = %JOSE.JWK{}, encrypted), do: block_decrypt(JOSE.JWK.to_record(jwk), encrypted)
+
+  def block_decrypt({your_public_jwk = %JOSE.JWK{}, my_private_jwk}, encrypted),
+    do: block_decrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, encrypted)
+
+  def block_decrypt({your_public_jwk, my_private_jwk = %JOSE.JWK{}}, encrypted),
+    do: block_decrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, encrypted)
+
   def block_decrypt(jwk, encrypted) do
     case :jose_jwe.block_decrypt(jwk, encrypted) do
       {plain_text, jwe} when is_tuple(jwe) ->
         {plain_text, from_record(jwe)}
+
       error ->
         error
     end
@@ -459,19 +468,29 @@ defmodule JOSE.JWE do
   @doc """
   Encrypts `plain_text` using the `jwk` and algorithm specified by the `jwe` by getting the `cek` for `block_encrypt/4`.
   """
-  def block_encrypt(jwk=%JOSE.JWK{}, plain_text, jwe), do: block_encrypt(JOSE.JWK.to_record(jwk), plain_text, jwe)
-  def block_encrypt({your_public_jwk=%JOSE.JWK{}, my_private_jwk}, plain_text, jwe), do: block_encrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, plain_text, jwe)
-  def block_encrypt({your_public_jwk, my_private_jwk=%JOSE.JWK{}}, plain_text, jwe), do: block_encrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, plain_text, jwe)
-  def block_encrypt(jwk, plain_text, jwe=%JOSE.JWE{}), do: block_encrypt(jwk, plain_text, to_record(jwe))
+  def block_encrypt(jwk = %JOSE.JWK{}, plain_text, jwe), do: block_encrypt(JOSE.JWK.to_record(jwk), plain_text, jwe)
+
+  def block_encrypt({your_public_jwk = %JOSE.JWK{}, my_private_jwk}, plain_text, jwe),
+    do: block_encrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, plain_text, jwe)
+
+  def block_encrypt({your_public_jwk, my_private_jwk = %JOSE.JWK{}}, plain_text, jwe),
+    do: block_encrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, plain_text, jwe)
+
+  def block_encrypt(jwk, plain_text, jwe = %JOSE.JWE{}), do: block_encrypt(jwk, plain_text, to_record(jwe))
   def block_encrypt(jwk, plain_text, jwe), do: :jose_jwe.block_encrypt(jwk, plain_text, jwe)
 
   @doc """
   Encrypts `plain_text` using the `jwk`, `cek`, and algorithm specified by the `jwe` by getting the `iv` for `block_encrypt/5`.
   """
-  def block_encrypt(jwk=%JOSE.JWK{}, plain_text, cek, jwe), do: block_encrypt(JOSE.JWK.to_record(jwk), plain_text, cek, jwe)
-  def block_encrypt({your_public_jwk=%JOSE.JWK{}, my_private_jwk}, plain_text, cek, jwe), do: block_encrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, plain_text, cek, jwe)
-  def block_encrypt({your_public_jwk, my_private_jwk=%JOSE.JWK{}}, plain_text, cek, jwe), do: block_encrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, plain_text, cek, jwe)
-  def block_encrypt(jwk, plain_text, cek, jwe=%JOSE.JWE{}), do: block_encrypt(jwk, plain_text, cek, to_record(jwe))
+  def block_encrypt(jwk = %JOSE.JWK{}, plain_text, cek, jwe), do: block_encrypt(JOSE.JWK.to_record(jwk), plain_text, cek, jwe)
+
+  def block_encrypt({your_public_jwk = %JOSE.JWK{}, my_private_jwk}, plain_text, cek, jwe),
+    do: block_encrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, plain_text, cek, jwe)
+
+  def block_encrypt({your_public_jwk, my_private_jwk = %JOSE.JWK{}}, plain_text, cek, jwe),
+    do: block_encrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, plain_text, cek, jwe)
+
+  def block_encrypt(jwk, plain_text, cek, jwe = %JOSE.JWE{}), do: block_encrypt(jwk, plain_text, cek, to_record(jwe))
   def block_encrypt(jwk, plain_text, cek, jwe), do: :jose_jwe.block_encrypt(jwk, plain_text, cek, jwe)
 
   @doc """
@@ -490,10 +509,16 @@ defmodule JOSE.JWE do
 
   See `block_decrypt/2`.
   """
-  def block_encrypt(jwk=%JOSE.JWK{}, plain_text, cek, iv, jwe), do: block_encrypt(JOSE.JWK.to_record(jwk), plain_text, cek, iv, jwe)
-  def block_encrypt({your_public_jwk=%JOSE.JWK{}, my_private_jwk}, plain_text, cek, iv, jwe), do: block_encrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, plain_text, cek, iv, jwe)
-  def block_encrypt({your_public_jwk, my_private_jwk=%JOSE.JWK{}}, plain_text, cek, iv, jwe), do: block_encrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, plain_text, cek, iv, jwe)
-  def block_encrypt(jwk, plain_text, cek, iv, jwe=%JOSE.JWE{}), do: block_encrypt(jwk, plain_text, cek, iv, to_record(jwe))
+  def block_encrypt(jwk = %JOSE.JWK{}, plain_text, cek, iv, jwe),
+    do: block_encrypt(JOSE.JWK.to_record(jwk), plain_text, cek, iv, jwe)
+
+  def block_encrypt({your_public_jwk = %JOSE.JWK{}, my_private_jwk}, plain_text, cek, iv, jwe),
+    do: block_encrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, plain_text, cek, iv, jwe)
+
+  def block_encrypt({your_public_jwk, my_private_jwk = %JOSE.JWK{}}, plain_text, cek, iv, jwe),
+    do: block_encrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, plain_text, cek, iv, jwe)
+
+  def block_encrypt(jwk, plain_text, cek, iv, jwe = %JOSE.JWE{}), do: block_encrypt(jwk, plain_text, cek, iv, to_record(jwe))
   def block_encrypt(jwk, plain_text, cek, iv, jwe), do: :jose_jwe.block_encrypt(jwk, plain_text, cek, iv, jwe)
 
   @doc """
@@ -518,7 +543,7 @@ defmodule JOSE.JWE do
 
   See `uncompress/2`.
   """
-  def compress(plain_text, jwe=%JOSE.JWE{}), do: compress(plain_text, to_record(jwe))
+  def compress(plain_text, jwe = %JOSE.JWE{}), do: compress(plain_text, to_record(jwe))
   def compress(plain_text, jwe), do: :jose_jwe.compress(plain_text, jwe)
 
   @doc """
@@ -545,8 +570,8 @@ defmodule JOSE.JWE do
         <<188, 156, 171, 224, 232, 231, 41, 250, 210, 117, 112, 219, 134, 218, 94, 50>>}}
 
   """
-  def generate_key(list) when is_list(list), do: for element <- list, into: [], do: generate_key(element)
-  def generate_key(jwe=%JOSE.JWE{}), do: generate_key(to_record(jwe))
+  def generate_key(list) when is_list(list), do: for(element <- list, into: [], do: generate_key(element))
+  def generate_key(jwe = %JOSE.JWE{}), do: generate_key(to_record(jwe))
   def generate_key(any), do: JOSE.JWK.from_record(:jose_jwe.generate_key(any))
 
   @doc """
@@ -561,10 +586,15 @@ defmodule JOSE.JWE do
 
   See `key_encrypt/3`.
   """
-  def key_decrypt(jwk=%JOSE.JWK{}, encrypted_key, jwe), do: key_decrypt(JOSE.JWK.to_record(jwk), encrypted_key, jwe)
-  def key_decrypt({your_public_jwk=%JOSE.JWK{}, my_private_jwk}, encrypted_key, jwe), do: key_decrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, encrypted_key, jwe)
-  def key_decrypt({your_public_jwk, my_private_jwk=%JOSE.JWK{}}, encrypted_key, jwe), do: key_decrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, encrypted_key, jwe)
-  def key_decrypt(jwk, encrypted_key, jwe=%JOSE.JWE{}), do: key_decrypt(jwk, encrypted_key, to_record(jwe))
+  def key_decrypt(jwk = %JOSE.JWK{}, encrypted_key, jwe), do: key_decrypt(JOSE.JWK.to_record(jwk), encrypted_key, jwe)
+
+  def key_decrypt({your_public_jwk = %JOSE.JWK{}, my_private_jwk}, encrypted_key, jwe),
+    do: key_decrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, encrypted_key, jwe)
+
+  def key_decrypt({your_public_jwk, my_private_jwk = %JOSE.JWK{}}, encrypted_key, jwe),
+    do: key_decrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, encrypted_key, jwe)
+
+  def key_decrypt(jwk, encrypted_key, jwe = %JOSE.JWE{}), do: key_decrypt(jwk, encrypted_key, to_record(jwe))
   def key_decrypt(jwk, encrypted_key, jwe), do: :jose_jwe.key_decrypt(jwk, encrypted_key, jwe)
 
   @doc """
@@ -584,14 +614,21 @@ defmodule JOSE.JWE do
 
   See `key_decrypt/3`.
   """
-  def key_encrypt(jwk=%JOSE.JWK{}, decrypted_key, jwe), do: key_encrypt(JOSE.JWK.to_record(jwk), decrypted_key, jwe)
-  def key_encrypt({your_public_jwk=%JOSE.JWK{}, my_private_jwk}, decrypted_key, jwe), do: key_encrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, decrypted_key, jwe)
-  def key_encrypt({your_public_jwk, my_private_jwk=%JOSE.JWK{}}, decrypted_key, jwe), do: key_encrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, decrypted_key, jwe)
-  def key_encrypt(jwk, decrypted_key, jwe=%JOSE.JWE{}), do: key_encrypt(jwk, decrypted_key, to_record(jwe))
+  def key_encrypt(jwk = %JOSE.JWK{}, decrypted_key, jwe), do: key_encrypt(JOSE.JWK.to_record(jwk), decrypted_key, jwe)
+
+  def key_encrypt({your_public_jwk = %JOSE.JWK{}, my_private_jwk}, decrypted_key, jwe),
+    do: key_encrypt({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, decrypted_key, jwe)
+
+  def key_encrypt({your_public_jwk, my_private_jwk = %JOSE.JWK{}}, decrypted_key, jwe),
+    do: key_encrypt({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, decrypted_key, jwe)
+
+  def key_encrypt(jwk, decrypted_key, jwe = %JOSE.JWE{}), do: key_encrypt(jwk, decrypted_key, to_record(jwe))
+
   def key_encrypt(jwk, decrypted_key, jwe) do
     case :jose_jwe.key_encrypt(jwk, decrypted_key, jwe) do
       {encrypted_key, jwe} when is_tuple(jwe) ->
         {encrypted_key, from_record(jwe)}
+
       error ->
         error
     end
@@ -600,8 +637,8 @@ defmodule JOSE.JWE do
   @doc """
   Merges map on right into map on left.
   """
-  def merge(left=%JOSE.JWE{}, right), do: merge(left |> to_record, right)
-  def merge(left, right=%JOSE.JWE{}), do: merge(left, right |> to_record)
+  def merge(left = %JOSE.JWE{}, right), do: merge(left |> to_record, right)
+  def merge(left, right = %JOSE.JWE{}), do: merge(left, right |> to_record)
   def merge(left, right), do: :jose_jwe.merge(left, right) |> from_record
 
   @doc """
@@ -618,10 +655,15 @@ defmodule JOSE.JWE do
       <<137, 211, 127, 99, 39, 152, 102, 161, 4, 236, 25, 41, 123, 24, 64, 217>>
 
   """
-  def next_cek(jwk=%JOSE.JWK{}, jwe), do: next_cek(JOSE.JWK.to_record(jwk), jwe)
-  def next_cek({your_public_jwk=%JOSE.JWK{}, my_private_jwk}, jwe), do: next_cek({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, jwe)
-  def next_cek({your_public_jwk, my_private_jwk=%JOSE.JWK{}}, jwe), do: next_cek({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, jwe)
-  def next_cek(jwk, jwe=%JOSE.JWE{}), do: next_cek(jwk, to_record(jwe))
+  def next_cek(jwk = %JOSE.JWK{}, jwe), do: next_cek(JOSE.JWK.to_record(jwk), jwe)
+
+  def next_cek({your_public_jwk = %JOSE.JWK{}, my_private_jwk}, jwe),
+    do: next_cek({JOSE.JWK.to_record(your_public_jwk), my_private_jwk}, jwe)
+
+  def next_cek({your_public_jwk, my_private_jwk = %JOSE.JWK{}}, jwe),
+    do: next_cek({your_public_jwk, JOSE.JWK.to_record(my_private_jwk)}, jwe)
+
+  def next_cek(jwk, jwe = %JOSE.JWE{}), do: next_cek(jwk, to_record(jwe))
   def next_cek(jwk, jwe), do: :jose_jwe.next_cek(jwk, jwe)
 
   @doc """
@@ -634,7 +676,7 @@ defmodule JOSE.JWE do
       96
 
   """
-  def next_iv(jwe=%JOSE.JWE{}), do: next_iv(to_record(jwe))
+  def next_iv(jwe = %JOSE.JWE{}), do: next_iv(to_record(jwe))
   def next_iv(jwe), do: :jose_jwe.next_iv(jwe)
 
   @doc """
@@ -645,7 +687,6 @@ defmodule JOSE.JWE do
 
   See `compress/2`.
   """
-  def uncompress(cipher_text, jwe=%JOSE.JWE{}), do: uncompress(cipher_text, to_record(jwe))
+  def uncompress(cipher_text, jwe = %JOSE.JWE{}), do: uncompress(cipher_text, to_record(jwe))
   def uncompress(cipher_text, jwe), do: :jose_jwe.uncompress(cipher_text, jwe)
-
 end
