@@ -1061,7 +1061,7 @@ data_setup(Config) ->
 data_setup(F = "186-3rsatestvectors.zip", Config) ->
 	Zip = archive_file(F, Config),
 	Dir = data_file("186-3rsatestvectors", Config),
-	URL = "http://csrc.nist.gov/groups/STM/cavp/documents/dss/186-3rsatestvectors.zip",
+	URL = "https://github.com/potatosalad/test-vector-archive/raw/1.0.0/archive/186-3rsatestvectors.zip",
 	ok = data_setup(Zip, Dir, URL),
 	Filter = fun
 		(#zip_file{name = "SigGenPSS_186-3.txt"}) ->
@@ -1076,7 +1076,7 @@ data_setup(F = "186-3rsatestvectors.zip", Config) ->
 data_setup(F = "aesmmt.zip", Config) ->
 	Zip = archive_file(F, Config),
 	Dir = data_file("aesmmt", Config),
-	URL = "http://csrc.nist.gov/groups/STM/cavp/documents/aes/aesmmt.zip",
+	URL = "https://github.com/potatosalad/test-vector-archive/raw/1.0.0/archive/aesmmt.zip",
 	ok = data_setup(Zip, Dir, URL),
 	Filter = fun
 		(#zip_file{name = "CBC" ++ _}) ->
@@ -1091,7 +1091,7 @@ data_setup(F = "aesmmt.zip", Config) ->
 data_setup(F = "gcmtestvectors.zip", Config) ->
 	Zip = archive_file(F, Config),
 	Dir = data_file("gcmtestvectors", Config),
-	URL = "http://csrc.nist.gov/groups/STM/cavp/documents/mac/gcmtestvectors.zip",
+	URL = "https://github.com/potatosalad/test-vector-archive/raw/1.0.0/archive/gcmtestvectors.zip",
 	ok = data_setup(Zip, Dir, URL),
 	case filelib:is_file(filename:join([Dir, "gcmDecrypt128.rsp"])) of
 		true ->
@@ -1109,7 +1109,7 @@ data_setup(F = "gcmtestvectors.zip", Config) ->
 data_setup(F = "KAT_AES.zip", Config) ->
 	Zip = archive_file(F, Config),
 	Dir = data_file("KAT_AES", Config),
-	URL = "http://csrc.nist.gov/groups/STM/cavp/documents/aes/KAT_AES.zip",
+	URL = "https://github.com/potatosalad/test-vector-archive/raw/1.0.0/archive/KAT_AES.zip",
 	ok = data_setup(Zip, Dir, URL),
 	Filter = fun
 		(#zip_file{name = "CBC" ++ _}) ->
@@ -1139,7 +1139,7 @@ data_setup(F = "keccaktestvectors", Config) ->
 data_setup(F = "kwtestvectors.zip", Config) ->
 	Zip = archive_file(F, Config),
 	Dir = data_file("kwtestvectors", Config),
-	URL = "http://csrc.nist.gov/groups/STM/cavp/documents/mac/kwtestvectors.zip",
+	URL = "https://github.com/potatosalad/test-vector-archive/raw/1.0.0/archive/kwtestvectors.zip",
 	ok = data_setup(Zip, Dir, URL),
 	Filter = fun
 		(#zip_file{name = "KW_" ++ Name}) ->
@@ -1157,7 +1157,7 @@ data_setup(F = "kwtestvectors.zip", Config) ->
 data_setup(F = "pkcs-1v2-1-vec.zip", Config) ->
 	Zip = archive_file(F, Config),
 	Dir = data_file("pkcs-1v2-1-vec", Config),
-	URL = "ftp://ftp.rsasecurity.com/pub/pkcs/pkcs-1/pkcs-1v2-1-vec.zip",
+	URL = "https://github.com/potatosalad/test-vector-archive/raw/1.0.0/archive/pkcs-1v2-1-vec.zip",
 	ok = data_setup(Zip, Dir, URL),
 	Filter = fun
 		(#zip_file{name = "oaep-vect.txt"}) ->
@@ -1506,8 +1506,8 @@ fips_aes_gcm_encrypt_and_decrypt([
 			andalso bit_size(CT) =:= PTlen
 			andalso bit_size(AAD) =:= AADlen
 			andalso bit_size(Tag) =:= Taglen ->
-	case crypto:rand_uniform(0, ?config(one_in, Config)) of
-		0 ->
+	case rand:uniform(?config(one_in, Config)) of
+		1 ->
 			case jose_jwa_aes:block_decrypt(Cipher, Key, IV, {AAD, CT, Tag}) of
 				error ->
 					fips_aes_gcm_encrypt_and_decrypt(Vectors, {Cipher, decrypt, {Keylen, IVlen, PTlen, AADlen, Taglen, << Counts/binary, (integer_to_binary(Count))/binary, "..." >>}}, Config);
@@ -1534,8 +1534,8 @@ fips_aes_gcm_encrypt_and_decrypt([
 			andalso bit_size(AAD) =:= AADlen
 			andalso bit_size(Tag) =:= Taglen
 			andalso bit_size(PT) =:= PTlen ->
-	case crypto:rand_uniform(0, ?config(one_in, Config)) of
-		0 ->
+	case rand:uniform(?config(one_in, Config)) of
+		1 ->
 			case jose_jwa_aes:block_decrypt(Cipher, Key, IV, {AAD, CT, Tag}) of
 				PT ->
 					fips_aes_gcm_encrypt_and_decrypt(Vectors, {Cipher, decrypt, {Keylen, IVlen, PTlen, AADlen, Taglen, << Counts/binary, (integer_to_binary(Count))/binary, "..." >>}}, Config);
@@ -1563,8 +1563,8 @@ fips_aes_gcm_encrypt_and_decrypt([
 			andalso bit_size(AAD) =:= AADlen
 			andalso bit_size(CT) =:= PTlen
 			andalso bit_size(Tag) =:= Taglen ->
-	case crypto:rand_uniform(0, ?config(one_in, Config)) of
-		0 ->
+	case rand:uniform(?config(one_in, Config)) of
+		1 ->
 			case jose_jwa_aes:block_encrypt(Cipher, Key, IV, {AAD, PT}) of
 				{CT, << Tag:Taglen/bitstring, _/bitstring >>} ->
 					fips_aes_gcm_encrypt_and_decrypt(Vectors, {Cipher, encrypt, {Keylen, IVlen, PTlen, AADlen, Taglen, << Counts/binary, (integer_to_binary(Count))/binary, "..." >>}}, Config);
@@ -1616,8 +1616,8 @@ fips_aeskw_unwrap([
 			when is_integer(Len)
 			andalso bit_size(K) =:= Bits
 			andalso bit_size(P) =:= Len ->
-	case crypto:rand_uniform(0, ?config(one_in, Config)) of
-		0 ->
+	case rand:uniform(?config(one_in, Config)) of
+		1 ->
 			case jose_jwa_aes_kw:unwrap(C, K) of
 				P ->
 					fips_aeskw_unwrap(Vectors, {Bits, Len}, Config);
@@ -1637,8 +1637,8 @@ fips_aeskw_unwrap([
 		], {Bits, Len}, Config)
 			when is_integer(Len)
 			andalso bit_size(K) =:= Bits ->
-	case crypto:rand_uniform(0, ?config(one_in, Config)) of
-		0 ->
+	case rand:uniform(?config(one_in, Config)) of
+		1 ->
 			try jose_jwa_aes_kw:unwrap(C, K) of
 				Other ->
 					io:format("\t\tCOUNT = ~w", [Count]),
@@ -1676,8 +1676,8 @@ fips_aeskw_wrap([
 			when is_integer(Len)
 			andalso bit_size(K) =:= Bits
 			andalso bit_size(P) =:= Len ->
-	case crypto:rand_uniform(0, ?config(one_in, Config)) of
-		0 ->
+	case rand:uniform(?config(one_in, Config)) of
+		1 ->
 			case jose_jwa_aes_kw:wrap(P, K) of
 				C ->
 					fips_aeskw_wrap(Vectors, {Bits, Len}, Config);
